-- ----------------------------
-- 部门信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dept`;
CREATE TABLE `mortals_xhx_dept` (
                                    `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键ID，主键，自增长',
                                    `parentId` bigint(20) DEFAULT NULL COMMENT '父id',
                                    `ancestors` varchar(256) NOT NULL COMMENT '祖级列表',
                                    `deptName` varchar(256) NOT NULL COMMENT '部门名称',
                                    `deptStatus` tinyint(2) NOT NULL DEFAULT '1' COMMENT '部门状态(0.停用,1.启用)',
                                    `orderNum` int(4) NOT NULL DEFAULT '0' COMMENT '顺序',
                                    `remark` varchar(256) DEFAULT NULL COMMENT '备注',
                                    `createUserId` bigint(20) NOT NULL COMMENT '创建用户',
                                    `createTime` datetime NOT NULL COMMENT '创建时间',
                                    `updateUserId` bigint(20) DEFAULT NULL COMMENT '更新用户',
                                    `updateTime` datetime DEFAULT NULL COMMENT '更新时间',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `deptStatus` (`deptStatus`) USING BTREE,
                                    KEY `orderNum` (`orderNum`) USING BTREE,
                                    KEY `createUserId` (`createUserId`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8 COMMENT='部门信息';


-- ----------------------------
-- 员工基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff`;
CREATE TABLE mortals_xhx_staff(
                                  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                  `name` varchar(64) NOT NULL     COMMENT '员工姓名',
                                  `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                  `birthday` datetime      COMMENT '出生日期',
                                  `photoPath` varchar(255)      COMMENT '照片',
                                  `phoneNumber` varchar(128)      COMMENT '联系电话',
                                  `idCard` varchar(128)      COMMENT '身份证号码',
                                  `workNum` varchar(128)      COMMENT '工号',
                                  `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                  `deptId` bigint(20)      COMMENT '所属部门',
                                  `deptName` varchar(128)      COMMENT '所属部门名称',
                                  `positionId` bigint(20)      COMMENT '职位ID',
                                  `positionName` varchar(128)      COMMENT '职位名称',
                                  `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型（1.全职,2.兼职,3.实习)',
                                  `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                  `registerPath` varchar(255)      COMMENT '入职登记表',
                                  `entryDate` datetime      COMMENT '入职时间',
                                  `regularDate` datetime      COMMENT '转正时间',
                                  `leaveDate` datetime      COMMENT '离职时间',
                                  `remark` varchar(255)      COMMENT '备注',
                                  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                  `createTime` datetime NOT NULL     COMMENT '创建时间',
                                  `updateUserId` bigint(20)      COMMENT '更新用户',
                                  `updateTime` datetime      COMMENT '更新时间',
                                  PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工基本信息';

-- ----------------------------
-- 员工关怀信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_care`;
CREATE TABLE mortals_xhx_staff_care(
                                       `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                       `staffId` bigint(20)      COMMENT '员工ID',
                                       `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                       `birthday` datetime      COMMENT '出生日期',
                                       `deptId` bigint(20)      COMMENT '所属部门',
                                       `deptName` varchar(128)      COMMENT '所属部门名称',
                                       `jobId` bigint(20)      COMMENT '职位ID',
                                       `jobName` varchar(128)      COMMENT '职位名称',
                                       `entryDate` datetime      COMMENT '入职时间',
                                       `careType` tinyint(2)    DEFAULT '1'  COMMENT '关怀类型(1.生日关怀,2.入职周年关怀)',
                                       `sendStatus` tinyint(2)    DEFAULT '0'  COMMENT '发送状态(0.未发送,1.已发送)',
                                       `content` text      COMMENT '关怀内容',
                                       `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                       `createTime` datetime NOT NULL     COMMENT '创建时间',
                                       `updateUserId` bigint(20)      COMMENT '更新用户',
                                       `updateTime` datetime      COMMENT '更新时间',
                                       PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工关怀信息';

-- ----------------------------
-- 关怀问候信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_care_template`;
CREATE TABLE mortals_xhx_care_template(
                                          `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                          `careType` tinyint(2)    DEFAULT '1'  COMMENT '关怀类型(1.生日关怀,2.入职周年关怀)',
                                          `sms` tinyint(2)    DEFAULT '1'  COMMENT '是否短信提示(1.是,0.否)',
                                          `smsTemplate` text      COMMENT '短信模板内容',
                                          `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                          `createTime` datetime NOT NULL     COMMENT '创建时间',
                                          `updateUserId` bigint(20)      COMMENT '更新用户',
                                          `updateTime` datetime      COMMENT '更新时间',
                                          PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='关怀问候信息';

-- ----------------------------
-- 职位信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_job`;
CREATE TABLE mortals_xhx_job(
                                `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
                                `groupId` bigint(20)      COMMENT '分组id',
                                `groupName` varchar(128)      COMMENT '分组名称',
                                `jobCode` varchar(128)      COMMENT '职位编码',
                                `jobName` varchar(128)      COMMENT '职位名称',
                                `remark` varchar(512)      COMMENT '备注',
                                `createTime` datetime      COMMENT '创建时间',
                                `createUserId` bigint(20)      COMMENT '创建用户',
                                `updateUserId` bigint(20)      COMMENT '更新用户',
                                `updateTime` datetime      COMMENT '修改时间',
                                PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='职位信息';

-- ----------------------------
-- 员工黑名单信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_black`;
CREATE TABLE mortals_xhx_staff_black(
                                        `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                        `staffId` bigint(20)      COMMENT '员工ID',
                                        `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                        `phoneNumber` varchar(128)      COMMENT '联系电话',
                                        `idCard` varchar(128)      COMMENT '身份证号码',
                                        `leaveDate` datetime      COMMENT '离职时间',
                                        `leaveReason` text      COMMENT '离职原因',
                                        `blackDate` datetime      COMMENT '拉黑时间',
                                        `blackReason` text      COMMENT '拉黑原因',
                                        `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                        `createTime` datetime NOT NULL     COMMENT '创建时间',
                                        `updateUserId` bigint(20)      COMMENT '更新用户',
                                        `updateTime` datetime      COMMENT '更新时间',
                                        PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工黑名单信息';

-- ----------------------------
-- 员工调岗信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_adjust_log`;
CREATE TABLE mortals_xhx_staff_adjust_log(
                                             `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                             `staffId` bigint(20)      COMMENT '员工ID',
                                             `fullName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                             `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别1男2女',
                                             `birthday` datetime      COMMENT '出生日期',
                                             `photoPath` varchar(255)      COMMENT '照片',
                                             `phoneNumber` varchar(128)      COMMENT '联系电话',
                                             `idCard` varchar(128)      COMMENT '身份证号码',
                                             `workNum` varchar(128)      COMMENT '工号',
                                             `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                             `deptId` bigint(20)      COMMENT '所属部门',
                                             `deptName` varchar(128)      COMMENT '所属部门名称',
                                             `jobId` bigint(20)      COMMENT '职位ID',
                                             `jobName` varchar(128)      COMMENT '职位名称',
                                             `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型1全职2兼职3实习',
                                             `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态1正式2试用3离职',
                                             `entryDate` datetime      COMMENT '入职时间',
                                             `newDeptId` bigint(20)      COMMENT '调岗后所属部门',
                                             `newDeptName` varchar(128)      COMMENT '调岗后所属部门名称',
                                             `newJobId` bigint(20)      COMMENT '调岗后职位ID',
                                             `newJobName` varchar(128)      COMMENT '调岗后职位名称',
                                             `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态0待审核1通过2拒绝',
                                             `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                             `createTime` datetime NOT NULL     COMMENT '创建时间',
                                             `updateUserId` bigint(20)      COMMENT '更新用户',
                                             `updateTime` datetime      COMMENT '更新时间',
                                             PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工调岗信息';

-- ----------------------------
-- 员工转正信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_regular`;
CREATE TABLE mortals_xhx_staff_regular(
                                          `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                          `staffId` bigint(20)      COMMENT '员工ID',
                                          `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                          `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                          `birthday` datetime      COMMENT '出生日期',
                                          `photoPath` varchar(255)      COMMENT '照片',
                                          `phoneNumber` varchar(128)      COMMENT '联系电话',
                                          `idCard` varchar(128)      COMMENT '身份证号码',
                                          `workNum` varchar(128)      COMMENT '工号',
                                          `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                          `deptId` bigint(20)      COMMENT '所属部门',
                                          `deptName` varchar(128)      COMMENT '所属部门名称',
                                          `jobId` bigint(20)      COMMENT '职位ID',
                                          `jobName` varchar(128)      COMMENT '职位名称',
                                          `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                          `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                          `entryDate` datetime      COMMENT '入职时间',
                                          `regularDate` datetime      COMMENT '计划转正时间',
                                          `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审核,1.通过,2.拒绝)',
                                          `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                          `createTime` datetime NOT NULL     COMMENT '创建时间',
                                          `updateUserId` bigint(20)      COMMENT '更新用户',
                                          `updateTime` datetime      COMMENT '更新时间',
                                          PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工转正信息';

-- ----------------------------
-- 员工离职信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_leave`;
CREATE TABLE mortals_xhx_staff_leave(
                                        `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                        `staffId` bigint(20)      COMMENT '员工ID',
                                        `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                        `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                        `birthday` datetime      COMMENT '出生日期',
                                        `photoPath` varchar(255)      COMMENT '照片',
                                        `phoneNumber` varchar(128)      COMMENT '联系电话',
                                        `idCard` varchar(128)      COMMENT '身份证号码',
                                        `workNum` varchar(128)      COMMENT '工号',
                                        `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                        `deptId` bigint(20)      COMMENT '所属部门',
                                        `deptName` varchar(128)      COMMENT '所属部门名称',
                                        `jobId` bigint(20)      COMMENT '职位ID',
                                        `jobName` varchar(128)      COMMENT '职位名称',
                                        `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                        `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                        `entryDate` datetime      COMMENT '入职时间',
                                        `leaveDate` datetime      COMMENT '离职时间',
                                        `leaveReason` text      COMMENT '离职原因',
                                        `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审,1.通过,2.拒绝)',
                                        `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                        `createTime` datetime NOT NULL     COMMENT '创建时间',
                                        `updateUserId` bigint(20)      COMMENT '更新用户',
                                        `updateTime` datetime      COMMENT '更新时间',
                                        PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工离职信息';

-- ----------------------------
-- 员工合同信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_contract`;
CREATE TABLE mortals_xhx_staff_contract(
                                           `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                           `staffId` bigint(20)      COMMENT '员工ID',
                                           `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                           `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                           `birthday` datetime      COMMENT '出生日期',
                                           `photoPath` varchar(255)      COMMENT '照片',
                                           `phoneNumber` varchar(128)      COMMENT '联系电话',
                                           `idCard` varchar(128)      COMMENT '身份证号码',
                                           `workNum` varchar(128)      COMMENT '工号',
                                           `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                           `deptId` bigint(20)      COMMENT '所属部门',
                                           `deptName` varchar(128)      COMMENT '所属部门名称',
                                           `jobId` bigint(20)      COMMENT '职位ID',
                                           `jobName` varchar(128)      COMMENT '职位名称',
                                           `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                           `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                           `entryDate` datetime      COMMENT '入职时间',
                                           `contractStartDate` datetime      COMMENT '现合同开始时间',
                                           `contractEndDate` datetime      COMMENT '现合同到期时间',
                                           `contractCompany` varchar(255)      COMMENT '合同公司',
                                           `contractType` tinyint(2)    DEFAULT '1'  COMMENT '合同类型(1.纸质)',
                                           `newStartDate` datetime      COMMENT '新合同开始时间',
                                           `newEndDate` datetime      COMMENT '新合同到期时间',
                                           `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审核,1.通过,2.拒绝)',
                                           `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                           `createTime` datetime NOT NULL     COMMENT '创建时间',
                                           `updateUserId` bigint(20)      COMMENT '更新用户',
                                           `updateTime` datetime      COMMENT '更新时间',
                                           PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工合同信息';

-- ----------------------------
-- 考勤打卡记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record`;
CREATE TABLE mortals_xhx_attendance_record(
                                              `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                              `staffId` bigint(20)      COMMENT '员工ID',
                                              `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                              `workNum` varchar(128)      COMMENT '工号',
                                              `deptId` bigint(20)      COMMENT '所属部门',
                                              `deptName` varchar(128)      COMMENT '所属部门名称',
                                              `positionId` bigint(20)      COMMENT '职位ID',
                                              `positionName` varchar(128)      COMMENT '职位名称',
                                              `attendanceGroupId` bigint(20)      COMMENT '所属考勤组ID',
                                              `attendanceGroupName` varchar(128)      COMMENT '所属考勤组名称',
                                              `shiftsId` bigint(20)      COMMENT '班次ID',
                                              `shiftsName` varchar(128)      COMMENT '班次名称',
                                              `attendanceDate` datetime      COMMENT '打卡日期',
                                              `remark` varchar(255)      COMMENT '备注',
                                              `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                              `createTime` datetime NOT NULL     COMMENT '创建时间',
                                              `updateUserId` bigint(20)      COMMENT '更新用户',
                                              `updateTime` datetime      COMMENT '更新时间',
                                              PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤打卡记录信息';

-- ----------------------------
-- 考勤打卡记录详细信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record_detail`;
CREATE TABLE mortals_xhx_attendance_record_detail(
                                                     `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                                     `recordId` bigint(20)      COMMENT '考勤记录ID',
                                                     `shiftsId` bigint(20)      COMMENT '班次ID',
                                                     `shiftsName` varchar(128)      COMMENT '班次名称',
                                                     `goWorkDate` datetime      COMMENT '上班打卡时间',
                                                     `goWorkResult` tinyint(2)      COMMENT '上班打卡结果(1.正常,2.请假,3.缺卡,4.迟到,5.早退)',
                                                     `offWorkDate` datetime      COMMENT '下班打卡时间',
                                                     `offWorkResult` tinyint(2)      COMMENT '下班打卡结果(1.正常,2.请假,3.缺卡,4.迟到,5.早退)',
                                                     `remark` varchar(255)      COMMENT '备注',
                                                     `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                                     `createTime` datetime NOT NULL     COMMENT '创建时间',
                                                     `updateUserId` bigint(20)      COMMENT '更新用户',
                                                     `updateTime` datetime      COMMENT '更新时间',
                                                     PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤打卡记录详细信息';

-- ----------------------------
-- 考勤组信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group`;
CREATE TABLE mortals_xhx_attendance_group(
                                             `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                             `groupName` varchar(128)      COMMENT '考勤组名称',
                                             `personNum` int(9)      COMMENT '人数',
                                             `responsiblePerson` varchar(128)      COMMENT '负责人',
                                             `type` tinyint(2)      COMMENT '类型(1.固定班指)',
                                             `attendanceTime` tinyint(2)      COMMENT '考勤时间',
                                             `remark` varchar(255)      COMMENT '备注',
                                             `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                             `createTime` datetime NOT NULL     COMMENT '创建时间',
                                             `updateUserId` bigint(20)      COMMENT '更新用户',
                                             `updateTime` datetime      COMMENT '更新时间',
                                             PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组信息';

-- ----------------------------
-- 考勤班次信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_class`;
CREATE TABLE mortals_xhx_attendance_class(
                                             `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                             `className` varchar(128)      COMMENT '班次名称',
                                             `classResponsiblePersonId` bigint(20)      COMMENT '班次负责人ID',
                                             `classResponsiblePersonName` varchar(128)      COMMENT '班次负责人名称',
                                             `remark` varchar(255)      COMMENT '备注',
                                             `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                             `createTime` datetime NOT NULL     COMMENT '创建时间',
                                             `updateUserId` bigint(20)      COMMENT '更新用户',
                                             `updateTime` datetime      COMMENT '更新时间',
                                             PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤班次信息';

-- ----------------------------
-- 考勤班次详细信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_class_detail`;
CREATE TABLE mortals_xhx_attendance_class_detail(
                                                    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                                    `shiftsId` bigint(20)      COMMENT '班次ID',
                                                    `shiftsName` varchar(128)      COMMENT '班次名称',
                                                    `goWorkDate` datetime      COMMENT '上班打卡时间',
                                                    `goWorkDateBefore` int(9)      COMMENT '上班打卡前时间段,单位分钟',
                                                    `goWorkDateAfter` int(9)      COMMENT '上班打卡前时间段,单位分钟',
                                                    `offWorkDate` datetime      COMMENT '下班打卡时间',
                                                    `offWorkDateBefore` int(9)      COMMENT '下班打卡前时间段,单位分钟',
                                                    `offWorkDateAfter` int(9)      COMMENT '下班打卡前时间段,单位分钟',
                                                    `remark` varchar(255)      COMMENT '备注',
                                                    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                                    `createTime` datetime NOT NULL     COMMENT '创建时间',
                                                    `updateUserId` bigint(20)      COMMENT '更新用户',
                                                    `updateTime` datetime      COMMENT '更新时间',
                                                    PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤班次详细信息';

-- ----------------------------
-- 请假记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_leave_record`;
CREATE TABLE mortals_xhx_attendance_leave_record(
                                                    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                                    `leavePersonId` bigint(20) NOT NULL     COMMENT '请假人id',
                                                    `leavePerson` varchar(64)      COMMENT '请假人',
                                                    `deptId` bigint(20)      COMMENT '所属部门id',
                                                    `deptName` varchar(256)      COMMENT '所属部门',
                                                    `phoneNumber` varchar(20)      COMMENT '电话号码',
                                                    `leaveType` tinyint(2)      COMMENT '请假类型(1.事假,2.调休,3.病假,4.年假,5.产假,6.陪产假,7.婚假,8.例假,9.哺乳假,10.丧假)',
                                                    `startTime` datetime      COMMENT '开始时间',
                                                    `endTime` datetime      COMMENT '结束时间',
                                                    `duration` int(9)      COMMENT '时长,单位秒',
                                                    `reason` text      COMMENT '请假事由',
                                                    `approverId` bigint(20)      COMMENT '审批负责人Id',
                                                    `approver` varchar(64)      COMMENT '审批负责人',
                                                    `attachment` varchar(255)      COMMENT '附件',
                                                    `attachmentPath` varchar(255)      COMMENT '附件路径',
                                                    `remark` varchar(255)      COMMENT '备注',
                                                    `createUserId` bigint(20)      COMMENT '创建用户',
                                                    `createTime` datetime      COMMENT '创建时间',
                                                    `updateUserId` bigint(20)      COMMENT '更新用户',
                                                    `updateTime` datetime      COMMENT '更新时间',
                                                    PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='请假记录信息';

-- ----------------------------
-- 员工假期余额信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_vacation_balance`;
CREATE TABLE mortals_xhx_attendance_vacation_balance(
                                                        `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                                        `staffId` bigint(20)      COMMENT '员工id',
                                                        `staffName` varchar(255)      COMMENT '员工姓名',
                                                        `deptId` bigint(20)      COMMENT '部门id',
                                                        `deptName` varchar(255)      COMMENT '部门名称',
                                                        `entryTime` datetime      COMMENT '入职时间',
                                                        `personalLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '事假（天）',
                                                        `compensatedLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '调休（天）',
                                                        `sickLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '病假（天）',
                                                        `annualLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '年假（天）',
                                                        `marriageLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '婚假（天）',
                                                        `remark` varchar(255)      COMMENT '备注',
                                                        `createUserId` bigint(20)      COMMENT '创建用户',
                                                        `createTime` datetime      COMMENT '创建时间',
                                                        `updateUserId` bigint(20)      COMMENT '更新用户',
                                                        `updateTime` datetime      COMMENT '更新时间',
                                                        PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工假期余额信息';

